OC.L10N.register(
    "spreed",
    {
    "a conversation" : "مکالمه",
    "(Duration %s)" : "(مدت زمان %s )",
    "You attended a call with {user1}" : "شما در تماس تلفنی با {user1} شرکت کردید",
    "_%n guest_::_%n guests_" : ["میهمان %n","میهمان ها %n"],
    "You attended a call with {user1} and {user2}" : "شما در یک تماس با {user1} و {user2} حضور پیدا کردید",
    "You attended a call with {user1}, {user2} and {user3}" : "شما در یک تماس با {user1} ، {user2} و {user3} شرکت کردید.",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "شما در یک تماس با {user1} ، {user2} و {user3} و {user4} شرکت کردید.",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "شما در یک تماس با {user1} ، {user2} ، {user3} ، {user4} و {user5} شرکت کردید.",
    "_%n other_::_%n others_" : ["دیگر %n","دیگران %n"],
    "{actor} invited you to {call}" : "{actor} شما را به {call} دعوت کرد",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "شما به یک <strong>مکالمه</strong> دعوت شده اید یا <strong>تماس</strong> گرفته اید",
    "Talk" : "گفتگو",
    "Guest" : "مهمان",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "به بحث نکست کلود خوش آمدید!\nدر این گفتگو از ویژگی های جدید موجود در نکست کلودTalk مطلع می شوید.",
    "New in Talk 6" : "جدید در Talk 6",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "اکنون می توان از Microsoft Edge و Safari برای شرکت در تماس های صوتی و تصویری استفاده کرد",
    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- مکالمات یک به یک هم اکنون برقرار است و دیگر نمی توان به طور تصادفی به مکالمه های گروهی تبدیل کرد. همچنین وقتی یکی از شرکت کنندگان مکالمه را ترک می کند ، مکالمه دیگر به طور خودکار حذف نمی شود. فقط در صورت ترک هر دو شرکت کننده ، مکالمه از سرور حذف می شود",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- اکنون می توانید با ارسال \"@all\" در گپ ، به همه شرکت کنندگان اطلاع دهید",
    "- With the \"arrow-up\" key you can repost your last message" : "- با کلید \"جهت بالا\" می توانید آخرین پیام خود را دوباره ارسال کنید",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- - بحث اکنون می تواند دستوراتی داشته باشد ، \"/ help\" را به عنوان یک پیام چت ارسال کنید تا ببینید سرپرست شما برخی از آنها را پیکربندی کرده است یا خیر",
    "- With projects you can create quick links between conversations, files and other items" : "- با پروژه ها می توانید پیوندهای سریع بین مکالمات ، پرونده ها و موارد دیگر ایجاد کنید",
    "New in Talk 7" : "جدید در Talk 7",
    "- You can now mention guests in the chat" : "- اکنون می توانید از مهمان ها در چت یاد کنید",
    "There are currently no commands available." : "در حال حاضر هیچ  فرمانی موجود نیست.",
    "The command does not exist" : "هیچ فرمان وجود ندارد",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "هنگام اجرای فرمان خطایی روی داد. لطفاً از سرپرست بخواهید که گزارش ها را بررسی کند.",
    "Talk updates ✅" : "به روزرسانی های Talk✅ ",
    "{actor} created the conversation" : "{actor} گفتگو را ایجاد کرد",
    "You created the conversation" : "شما گفتگو را ایجاد کردید",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} این گفتگو را از \" %1$s \" به \"%2$s\" تغییر نام داد",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "شما این گفتگو را از \"%1$s \" به \"%2$s\" تغییر نام داد",
    "{actor} started a call" : "{actor} یک تماس را شروع کرد",
    "You started a call" : "شما یک تماس را شروع کردید",
    "{actor} joined the call" : "{actor} به تماس پیوست",
    "You joined the call" : "شما به تماس پیوستید",
    "{actor} left the call" : "{actor} تماس را ترک کرد",
    "You left the call" : "شما تماس را ترک کردید",
    "{actor} unlocked the conversation" : "{actor} مکالمه را باز کرد",
    "You unlocked the conversation" : "شما مکالمه را باز کردید",
    "{actor} locked the conversation" : "{actor} مکالمه را قفل کرد",
    "You locked the conversation" : "شما مکالمه را قفل کرد",
    "The conversation is now open to everyone" : "اکنون این گفتگو برای همه باز است",
    "{actor} opened the conversation to everyone" : "{actor} گفتگو را برای همه باز کرد",
    "You opened the conversation to everyone" : "شما گفتگو را برای همه باز کردید",
    "{actor} restricted the conversation to moderators" : "{actor} گفتگو را محدود به ناظران کرد",
    "You restricted the conversation to moderators" : "شما گفتگو را محدود به ناظران کردید",
    "{actor} allowed guests" : "{actor} مهمان مجاز است",
    "You allowed guests" : "شما به مهمان ها اجازه دادید.",
    "{actor} disallowed guests" : "{actor} مهمانان مجاز نیستند",
    "You disallowed guests" : "شما میهمانان را مجاز نکردید",
    "{actor} set a password" : "{actor} یک رمزعبور تنظیم می کنید",
    "You set a password" : "شما یک رمزعبور تنظیم می کنید",
    "{actor} removed the password" : "{actor} رمز عبور را حذف کرد",
    "You removed the password" : "شما رمز عبور را حذف کردید",
    "{actor} added {user}" : "{actor} کاربر {user} را اضافه کرد",
    "You joined the conversation" : "شما به گفتگو پیوستید",
    "{actor} joined the conversation" : "{actor} به گفتگو پیوست",
    "You added {user}" : "شما {user} را اضافه کردید",
    "{actor} added you" : "{actor} شما را اضافه کرد",
    "You left the conversation" : "گفتگو را ترک کردید",
    "{actor} left the conversation" : "{actor} گفتگو را ترک کرد",
    "{actor} removed {user}" : "{actor} {user} را حذف کرد",
    "You removed {user}" : "شما {user} را حذف کردید",
    "{actor} removed you" : "{actor} شما را حذف کرد",
    "{actor} promoted {user} to moderator" : "{actor} {user} را به عنوان ناظر تبلیغ کرد",
    "You promoted {user} to moderator" : "شما {user} را به عنوان مجری تبلیغ کردید",
    "{actor} promoted you to moderator" : "{actor} شما را به سمت مجری ارتقاء داد",
    "{actor} demoted {user} from moderator" : "{actor} {user} را از مجری دور کرد",
    "You demoted {user} from moderator" : "شما {user} را از مجری خلع کردید",
    "{actor} demoted you from moderator" : "{actor} شما را از مجری دور کرد",
    "{actor} shared a file which is no longer available" : "{actor} فایلی را به اشتراک گذاشت که دیگر در دسترس نیست",
    "You shared a file which is no longer available" : "شما یک پرونده را به اشتراک گذاشتید که دیگر در دسترس نیست",
    "%s (guest)" : "%s (مهمان)",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["تماس با %n مهمان (مدت زمان {duration})","تماس با %n مهمانان (مدت زمان {duration})"],
    "Call with {user1} and {user2} (Duration {duration})" : "تماس با {user1} و {user2} (مدت زمان {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "تماس با {user1} ، {user2} و {user3} (مدت زمان {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "تماس با {user1} ، {user2} ، {user3} و {user4} (مدت زمان {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "تماس با {user1} ، {user2} ، {user3} ، {user4} و {user5} (مدت زمان {duration})",
    "Talk to %s" : "صحبت کردن %s",
    "File is not shared, or shared but not with the user" : "پرونده به اشتراک گذاشته نمی شود ، یا به اشتراک گذاشته اما با کاربر به اشتراک گذاشته نمی شود",
    "Write to conversation" : "برای مکالمه بنویسید",
    "Writes event information into a conversation of your choice" : "اطلاعات رویداد را در گفتگوی مورد نظر شما می نویسد",
    "%s invited you to a conversation." : "%s شما را به یک گفتگو دعوت کرد",
    "You were invited to a conversation." : "شما به یک گفتگو دعوت شده اید",
    "Private conversation" : "مکالمه خصوصی",
    "{user} invited you to a private conversation" : "{user} شما را به یک گفتگوی خصوصی دعوت کرد",
    "{user} invited you to a group conversation: {call}" : "{user} شما را به یک گفتگو گروهی دعوت کرد: {call}",
    "Open settings" : "تنظیمات را باز کنید",
    "United Arab Emirates" : "امارات متحده عربی",
    "Afghanistan" : "افغانستان",
    "Albania" : "آلبانی",
    "Armenia" : "ارمنستان",
    "Angola" : "آنگولا",
    "Argentina" : "آرژانتین",
    "Austria" : "استرالیا",
    "Australia" : "استرالیا",
    "Azerbaijan" : "آذربایجان",
    "Bangladesh" : "بنگلادش",
    "Belgium" : "بلژیک",
    "Burkina Faso" : "بورکینافاسو",
    "Bulgaria" : "بلغارستان",
    "Burundi" : "بوروندی",
    "Benin" : "بنین",
    "Brazil" : "برزیل",
    "Bahamas" : "باهاما",
    "Bhutan" : "بوتان",
    "Botswana" : "بوتسوانا",
    "Belarus" : "بلاروس",
    "Belize" : "بلیز",
    "Canada" : "کانادا",
    "Central African Republic" : "جمهوری آفریقای مرکزی",
    "Congo" : "کنگو",
    "Switzerland" : "سوئیس",
    "Chile" : "شیلی",
    "Cameroon" : "کامرون",
    "China" : "چین",
    "Colombia" : "کلومبیا",
    "Costa Rica" : "کاستاریکا",
    "Cuba" : "کوبا",
    "Cyprus" : "قبرس",
    "Germany" : "آلمان",
    "Djibouti" : "جیبوتی",
    "Denmark" : "دانمارک",
    "Dominican Republic" : "جمهوری دومینیکن",
    "Algeria" : "الجزایر",
    "Ecuador" : "اکوادور",
    "Estonia" : "استونی",
    "Egypt" : "مصر",
    "Eritrea" : "اریتره",
    "Spain" : "اسپانیا",
    "Ethiopia" : "اتیوپی",
    "Finland" : "فنلاند",
    "Fiji" : "فیجی",
    "France" : "فرانسه",
    "Gabon" : "گابن",
    "Georgia" : "جورجیا",
    "Ghana" : "غنا",
    "Greenland" : "گرینلند",
    "Gambia" : "گامبیا",
    "Guinea" : "گینه",
    "Equatorial Guinea" : "گینه استوایی",
    "Greece" : "یونان",
    "Guatemala" : "گواتمالا",
    "Guinea-Bissau" : "گینه بیسائو",
    "Guyana" : "گویان",
    "Honduras" : "هندوراس",
    "Croatia" : "کرواسی",
    "Haiti" : "هائیتی",
    "Hungary" : "مجارستان",
    "Indonesia" : "اندونزی",
    "Ireland" : "ایرلند",
    "Israel" : "اسرائیل",
    "India" : "هند",
    "Iraq" : "عراق",
    "Iceland" : "ایسلند",
    "Italy" : "ایتالیا",
    "Jamaica" : "جامایکا",
    "Jordan" : "جردن",
    "Japan" : "ژاپن",
    "Kenya" : "کنیا",
    "Kyrgyzstan" : "قرقیزستان",
    "Cambodia" : "کمبوج",
    "Kuwait" : "کویت",
    "Kazakhstan" : "قزاقستان",
    "Lebanon" : "لبنان",
    "Sri Lanka" : "سریلانکا",
    "Liberia" : "لیبریا",
    "Lesotho" : "لسوتو",
    "Lithuania" : "لیتوانی",
    "Luxembourg" : "لوکزامبورگ",
    "Latvia" : "لتونی",
    "Libya" : "لیبی",
    "Morocco" : "مراکش",
    "Montenegro" : "مونتنگرو",
    "Madagascar" : "ماداگاسکار",
    "Mali" : "مالی",
    "Myanmar" : "میانمار",
    "Mongolia" : "مغولستان",
    "Mauritania" : "موریتانی",
    "Malawi" : "مالاوی",
    "Mexico" : "مکزیک",
    "Malaysia" : "مالزی",
    "Mozambique" : "موزامبیک",
    "Namibia" : "ناميبيا",
    "New Caledonia" : "کالدونیای جدید",
    "Niger" : "نیجر",
    "Nigeria" : "نیجرا",
    "Nicaragua" : "نیجریه",
    "Netherlands" : "هلند",
    "Norway" : "نروژ",
    "Nepal" : "نپال",
    "New Zealand" : "نیوزلند",
    "Oman" : "عمان",
    "Panama" : "پاناما",
    "Peru" : "پرو",
    "Papua New Guinea" : "پاپوا گینه نو",
    "Philippines" : "فلیپین",
    "Pakistan" : "پاکستان",
    "Poland" : "لهستان",
    "Puerto Rico" : "پورتوریکو",
    "Portugal" : "پرتغال",
    "Paraguay" : "پاروگیه",
    "Qatar" : "قطر",
    "Romania" : "رومانی",
    "Serbia" : "صربستان",
    "Rwanda" : "رواندا",
    "Saudi Arabia" : "عربستان",
    "Solomon Islands" : "جزایر سلیمان",
    "Sudan" : "سودان",
    "Sweden" : "سوئد",
    "Singapore" : "سنگاپور",
    "Slovenia" : "اسلونی",
    "Slovakia" : "اسلواکی",
    "Sierra Leone" : "سیرا لئون",
    "Senegal" : "سنگال",
    "Somalia" : "سومالی",
    "Suriname" : "سوریه",
    "South Sudan" : "سومالی شمالی",
    "El Salvador" : "سلوادور",
    "Chad" : "چد",
    "Togo" : "توگو",
    "Thailand" : "تایلند",
    "Tajikistan" : "تاجیکستان",
    "Timor-Leste" : "تیمور-لست",
    "Turkmenistan" : "ترکمنستان",
    "Tunisia" : "تونس",
    "Tonga" : "تونگا",
    "Turkey" : "jv;di",
    "Trinidad and Tobago" : "ترینیداد و توباگو",
    "Ukraine" : "اوکراین",
    "Uganda" : "اوگاندا",
    "Uruguay" : "اوروگویه",
    "Uzbekistan" : "اوزبکستان",
    "Vanuatu" : "وانتویو",
    "Yemen" : "یمن",
    "South Africa" : "آفریقا شمالی",
    "Zambia" : "زامبی",
    "Zimbabwe" : "زیمباوه",
    "Invalid date, date format must be YYYY-MM-DD" : "تاریخ نامعتبر است ، قالب تاریخ باید YYYY-MM-DD باشد",
    "Join conversation" : "عضویت در گفتگو",
    "Limit to groups" : "محدود کردن به گروه ها",
    "Everyone" : "همه",
    "Save changes" : "ذخیره تغییرات",
    "Saved!" : "ذخیره!",
    "None" : "هیچ‌کدام",
    "User" : "User",
    "Disabled" : "غیرفعال شده",
    "Users" : "کاربران",
    "Name" : "نام",
    "General settings" : "تنظیمات عمومی",
    "Off" : "خاموش",
    "Language" : "زبان",
    "Country" : "کشور",
    "Status" : "وضعیت",
    "Created at" : "ایجاد شده در",
    "Pending" : "در انتظار",
    "Error" : "خطا",
    "Blocked" : "مسدود کردن",
    "Active" : "فعال کردن",
    "Expired" : "منقضی شده",
    "Saved" : "ذخیره شد",
    "Copy link" : "کپی کردن لینک",
    "You can invite others in the participant tab of the sidebar" : "شما می‌توانید دیگران را از زبانه اعضا در نوارکناری دعوت کنید",
    "Share this link to invite others!" : "این پیوند را به اشتراک بگذارید تا دیگران را دعوت کنید!",
    "Dismiss" : "پنهان کن",
    "You" : "شما",
    "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
    "Favorite" : "برگزیده",
    "Leave conversation" : "ترک صحبت",
    "Delete conversation" : "مکالمه را حذف کنید",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "در حال بار گزاری",
    "Groups" : "گروه ها",
    "Circles" : "حلقه ها",
    "Create a new group conversation" : "ساخت گفتگوی گروهی جدید",
    "Password protect" : "نگهداری کردن رمز عبور",
    "Add participants" : "افزودن عضو",
    "Back" : "بازگشت",
    "Close" : "بستن",
    "Conversation name" : "نام مکالمه",
    "Allow guests to join via link " : "مجاز بودن عضویت مهمان‌ها با پیوند",
    "Reply" : "پاسخ",
    "Today" : "Today",
    "Yesterday" : "دیروز",
    "Send message" : "پیام فرستادن",
    "guest" : "میهمان",
    "Demote from moderator" : "عزل از مدیر",
    "Promote to moderator" : "ترفیع به مدیر",
    "Remove participant" : "شرکت کننده را حذف کنید",
    "Searching …" : "جستجوکردن …",
    "No results" : "نتیجه ای یافت نشد",
    "Add users or groups" : "کاربران یا گروه ها را اضافه کنید",
    "Add participants to the conversation" : "افزودن عضو به گفتگو",
    "Participants" : "شركت كنندگان",
    "Projects" : "پروژه ها",
    "Settings" : "تنظیمات",
    "Edit" : "ویرایش",
    "Rename conversation" : "تغییر نام مکالمه",
    "Share link" : "Share link",
    "Password protection" : "Password protection",
    "Enter a password" : "یک گذرواژه وارد کنید",
    "Fullscreen (f)" : "تمام صفحه (f)",
    "Grid view" : "نمایش گرید",
    "Join a conversation or start a new one!" : "عضو یک گفتگو شوید یا یک گفتگو جدید شروع کنید!",
    "Join a conversation or start a new one" : "عضو یک گفتگو شوید یا یک گفتگو جدید شروع کنید",
    "Say hi to your friends and colleagues!" : "به رفقا و همدرس‌هایتان سلام کنید!",
    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
    "Password" : "گذرواژه",
    "Android app" : "اپ اندروید",
    "iOS app" : "اپ iOS",
    "Copy" : "کپی کردن",
    "Copied!" : "کپی انجام شد!",
    "Not supported!" : "پشتیبانی وجود ندارد!",
    "Press ⌘-C to copy." : "برای کپی کردن از دکمه های C+⌘ استفاده نمایید",
    "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
    "Password required" : "رمز عبور لازم است",
    "Cancel" : "لغو",
    "Submit" : "ارسال",
    "Guests" : "میهمان ها",
    "Webinar" : "وبینار",
    "Change password" : "تغییر گذر واژه",
    "Set password" : "قراردادن رمز عبور",
    "Rename" : "تغییرنام",
    "Send" : "ارسال",
    "Share" : "هم‌رسانی",
    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
    "Add participant …" : "افزودن اعضا ...",
    "Favorited" : "برگزیده شده",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- مکالمات اکنون می توانند یک لابی داشته باشند. این به مدیران اجازه می دهد تا برای تهیه جلسه به چت بپیوندند و از قبل تماس بگیرند ، در حالی که کاربران و میهمانان باید منتظر بمانند.",
    "Contacts" : "مخاطبین"
},
"nplurals=2; plural=(n > 1);");
